==> kdebase-4.1.2.tar.bz2: kdebase-4.1.2/apps/dolphin/src/statusbarspaceinfo.cpp <==
/***************************************************************************
 *   Copyright (C) 2006 by Peter Penz (peter.penz@gmx.at) and              *
 *   and Patrice Tremblay                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#include "statusbarspaceinfo.h"

#include <kdiskfreespace.h>
#include <kmountpoint.h>
#include <klocale.h>
#include <kio/job.h>

#include <QTimer>
#include <QKeyEvent>

StatusBarSpaceInfo::StatusBarSpaceInfo(QWidget* parent) :
    QProgressBar(parent),
    m_gettingSize(false),
    m_foundMountPoint(false),
    m_text()
{
    setMinimum(0);
    setMaximum(0);

    setMaximumWidth(200);

    // Update the space information each 10 seconds. Polling is useful
    // here, as files can be deleted/added outside the scope of Dolphin.
    QTimer* timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(refresh()));
    timer->start(10000);
}

StatusBarSpaceInfo::~StatusBarSpaceInfo()
{
}

void StatusBarSpaceInfo::setUrl(const KUrl& url)
{
    m_url = url;
    refresh();
}

QString StatusBarSpaceInfo::text() const
{
    return m_text;
}

void StatusBarSpaceInfo::slotFoundMountPoint(const QString& mountPoint,
                                             quint64 kBSize,
                                             quint64 kBUsed,
                                             quint64 kBAvailable)
{
    Q_UNUSED(mountPoint);

    m_gettingSize = false;
    m_foundMountPoint = true;
    const bool valuesChanged = (kBUsed != static_cast<quint64>(value())) ||
                               (kBSize != static_cast<quint64>(maximum()));
    if (valuesChanged) {
        m_text = i18nc("@info:status Free disk space", "%1 free", KIO::convertSize(kBAvailable * 1024));
        setUpdatesEnabled(false);
        setMaximum(kBSize);
        setValue(kBUsed);
        setUpdatesEnabled(true);
        update();
    }
}

void StatusBarSpaceInfo::slotDiskFreeSpaceDone()
{
    if (m_foundMountPoint) {
        return;
    }

    m_gettingSize = false;
    m_text = i18nc("@info:status", "Unknown size");
    setValue(0);
    update();
}

void StatusBarSpaceInfo::refresh()
{
    // KDiskFreeSpace is for local paths only
    if (!m_url.isLocalFile()) {
        m_text = i18nc("@info:status", "Unknown size");
        setValue(0);
        update();
        return;
    }

    KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath(m_url.path());
    if (!mp) {
        return;
    }

    m_gettingSize = true;
    m_foundMountPoint = false;
    KDiskFreeSpace* job = new KDiskFreeSpace(this);
    connect(job, SIGNAL(foundMountPoint(const QString&,
                                        quint64,
                                        quint64,
                                        quint64)),
            this, SLOT(slotFoundMountPoint(const QString&,
                                           quint64,
                                           quint64,
                                           quint64)));
    connect(job, SIGNAL(done()), this, SLOT(slotDiskFreeSpaceDone()));

    job->readDF(mp->mountPoint());

    // refresh() is invoked for each directory change. Usually getting
    // the size information can be done very fast, so to prevent any
    // flickering the "Getting size..." indication is only shown if
    // at least 300 ms have been passed.
    QTimer::singleShot(300, this, SLOT(showGettingSizeInfo()));
}

void StatusBarSpaceInfo::showGettingSizeInfo()
{
    if (m_gettingSize) {
        m_text = i18nc("@info:status", "Getting size...");
        setMaximum(0);
        update();
    }
}

#include "statusbarspaceinfo.moc"

==> kdebase-4.2.2.tar.bz2: kdebase-4.2.2/apps/dolphin/src/statusbarspaceinfo.cpp <==
/***************************************************************************
 *   Copyright (C) 2006 by Peter Penz (peter.penz@gmx.at) and              *
 *   and Patrice Tremblay                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#include "statusbarspaceinfo.h"

#include <KDiskFreeSpaceInfo>
#include <kmountpoint.h>
#include <klocale.h>
#include <kio/job.h>

#include <QTimer>
#include <QKeyEvent>

StatusBarSpaceInfo::StatusBarSpaceInfo(QWidget* parent) :
    KCapacityBar(KCapacityBar::DrawTextInline, parent),
    m_kBSize(0),
    m_timer(0)
{
    setMaximumWidth(200);
    setMinimumWidth(200); // something to fix on kcapacitybar (ereslibre)

    // Use a timer to update the space information. Polling is useful
    // here, as files can be deleted/added outside the scope of Dolphin.
    m_timer = new QTimer(this);
    connect(m_timer, SIGNAL(timeout()), this, SLOT(refresh()));
}

StatusBarSpaceInfo::~StatusBarSpaceInfo()
{
}

void StatusBarSpaceInfo::setUrl(const KUrl& url)
{
    m_url = url;
    refresh();
}

void StatusBarSpaceInfo::showEvent(QShowEvent* event)
{
    KCapacityBar::showEvent(event);
    if (!event->spontaneous()) {
        refresh();
        m_timer->start(10000);
    }
}

void StatusBarSpaceInfo::hideEvent(QHideEvent* event)
{
    m_timer->stop();
    KCapacityBar::hideEvent(event);
}

void StatusBarSpaceInfo::refresh()
{
    if (!isVisible()) {
        return;
    }

    // KDiskFreeSpace is for local paths only
    if (!m_url.isLocalFile()) {
        setText(i18nc("@info:status", "Unknown size"));
        setValue(0);
        update();
        return;
    }

    KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath(m_url.path());
    if (!mp) {
        return;
    }

    KDiskFreeSpaceInfo job = KDiskFreeSpaceInfo::freeSpaceInfo(mp->mountPoint());
    if (!job.isValid()) {
        setText(i18nc("@info:status", "Unknown size"));
        setValue(0);
        update();
        return;
    }

    KIO::filesize_t kBSize = job.size() / 1024;
    KIO::filesize_t kBUsed = job.used() / 1024;

    const bool valuesChanged = (kBUsed != static_cast<quint64>(value())) || (kBSize != m_kBSize);
    if (valuesChanged) {
        setText(i18nc("@info:status Free disk space", "%1 free",
                KIO::convertSize(job.available())));

        setUpdatesEnabled(false);
        m_kBSize = kBSize;
        setValue(kBSize > 0 ? (kBUsed * 100) / kBSize : 0);
        setUpdatesEnabled(true);
        update();
    }
}

#include "statusbarspaceinfo.moc"
